@@ -206,13 +206,6 @@ class GraphAPI(object):
             while url:
                 result, url = load(method, url, data)
 
-                # If number of results is smaller than the limit parameter passed, there's no need to query an extra page
-                qs = parse_qs(urlparse(url).query)
-                if 'limit' in qs:
-                    limit = int(qs['limit'][0])
-                    if len(result['data']) < limit:
-                        url = None
-
                 # Reset pagination parameters.
                 for key in ['offset', 'until', 'since']:
                     try:
